pub struct HttpOptions {
pub allow_invalid_certs: bool,
pub cache_dir: Option<PathBuf>,
pub proxies: Vec<String>,
pub retry_count: Option<u32>,
pub secure_proxies: Vec<String>,
pub root_cert: Option<PathBuf>,
}Expand description
Configures the HTTP(S) client used for making requests.
Fields
allow_invalid_certs: boolAllow invalid certificates. This is dangerous and should only be used as a last resort!
cache_dir: Option<PathBuf>Absolute path to a directory in which to cache GET and HEAD requests.
proxies: Vec<String>A list of proxy URLs that all requests should pass through. URLs that start with
http: will handle insecure requests, while https: will handle secure requests.
retry_count: Option<u32>Maximum number of times to retry a request if it fails due to a transient error.
secure_proxies: Vec<String>A list of proxy URLs that all https: requests should pass through.
root_cert: Option<PathBuf>Absolute path to the root certificate. Supports .pem and .der files.