PluginContainer

Struct PluginContainer 

pub struct PluginContainer {
    pub id: Id,
    pub manifest: Manifest,
    pub virtual_paths: Vec<(PathBuf, PathBuf)>,
    /* private fields */
}
A container around Extism’s Plugin and Manifest types that provides convenience methods for calling and caching functions from the WASM plugin. It also provides additional methods for easily working with WASI and virtual paths.

Fields

id: Idmanifest: Manifestvirtual_paths: Vec<(PathBuf, PathBuf)>

Implementations

Source

impl PluginContainer

pub fn new( id: Id, manifest: Manifest, functions: impl IntoIterator<Item = Function>, ) -> Result<PluginContainer, WarpgatePluginError>

Create a new container with the provided manifest and host functions.

pub fn new_without_functions( id: Id, manifest: Manifest, ) -> Result<PluginContainer, WarpgatePluginError>

Create a new container with the provided manifest.

pub fn set_on_call(&self, func: OnCallFn)

Set a callback handler to be executed when calling a plugin function.

pub async fn cache_func<F, O>(&self, func: F) -> Result<O, WarpgatePluginError>
where F: Debug + AsRef<str>, O: Debug + DeserializeOwned,

Call a function on the plugin with no input and cache the output before returning it. Subsequent calls will read from the cache.

pub async fn cache_func_with<F, I, O>( &self, func: F, input: I, ) -> Result<O, WarpgatePluginError>

Call a function on the plugin with the given input and cache the output before returning it. Subsequent calls with the same input will read from the cache.

pub async fn call_func<F, O>(&self, func: F) -> Result<O, WarpgatePluginError>
where F: Debug + AsRef<str>, O: Debug + DeserializeOwned,

Call a function on the plugin with no input and return the output.

pub async fn call_func_with<F, I, O>( &self, func: F, input: I, ) -> Result<O, WarpgatePluginError>

Call a function on the plugin with the given input and return the output.

pub async fn call_func_without_output<F, I>( &self, func: F, input: I, ) -> Result<(), WarpgatePluginError>
where F: Debug + AsRef<str>, I: Debug + Serialize,

Call a function on the plugin with the given input and ignore the output.

pub async fn has_func(&self, func: impl AsRef<str>) -> bool

Return true if the plugin has a function with the given id.

pub fn from_virtual_path(&self, path: impl AsRef<Path> + Debug) -> PathBuf

Convert the provided virtual guest path to an absolute host path.

pub fn to_virtual_path(&self, path: impl AsRef<Path> + Debug) -> VirtualPath

Convert the provided absolute host path to a virtual guest path suitable for WASI sandboxed runtimes.

pub async fn call( &self, func: &str, input: impl AsRef<[u8]>, ) -> Result<Vec<u8>, WarpgatePluginError>

Call a function on the plugin with the given raw input and return the raw output.