pub struct PluginContainer {
pub id: Id,
pub manifest: Manifest,
pub virtual_paths: Vec<(PathBuf, PathBuf)>,
/* private fields */
}Expand description
Fields
id: Idmanifest: Manifestvirtual_paths: Vec<(PathBuf, PathBuf)>Implementations
Sourceimpl PluginContainer
impl PluginContainer
Sourcepub fn new(
id: Id,
manifest: Manifest,
functions: impl IntoIterator<Item = Function>,
) -> Result<PluginContainer, WarpgatePluginError>
pub fn new( id: Id, manifest: Manifest, functions: impl IntoIterator<Item = Function>, ) -> Result<PluginContainer, WarpgatePluginError>
Create a new container with the provided manifest and host functions.
Sourcepub fn new_without_functions(
id: Id,
manifest: Manifest,
) -> Result<PluginContainer, WarpgatePluginError>
pub fn new_without_functions( id: Id, manifest: Manifest, ) -> Result<PluginContainer, WarpgatePluginError>
Create a new container with the provided manifest.
Sourcepub fn set_on_call(&self, func: OnCallFn)
pub fn set_on_call(&self, func: OnCallFn)
Set a callback handler to be executed when calling a plugin function.
Sourcepub async fn cache_func<F, O>(&self, func: F) -> Result<O, WarpgatePluginError>
pub async fn cache_func<F, O>(&self, func: F) -> Result<O, WarpgatePluginError>
Call a function on the plugin with no input and cache the output before returning it. Subsequent calls will read from the cache.
Sourcepub async fn cache_func_with<F, I, O>(
&self,
func: F,
input: I,
) -> Result<O, WarpgatePluginError>
pub async fn cache_func_with<F, I, O>( &self, func: F, input: I, ) -> Result<O, WarpgatePluginError>
Call a function on the plugin with the given input and cache the output before returning it. Subsequent calls with the same input will read from the cache.
Sourcepub async fn call_func<F, O>(&self, func: F) -> Result<O, WarpgatePluginError>
pub async fn call_func<F, O>(&self, func: F) -> Result<O, WarpgatePluginError>
Call a function on the plugin with no input and return the output.
Sourcepub async fn call_func_with<F, I, O>(
&self,
func: F,
input: I,
) -> Result<O, WarpgatePluginError>
pub async fn call_func_with<F, I, O>( &self, func: F, input: I, ) -> Result<O, WarpgatePluginError>
Call a function on the plugin with the given input and return the output.
Sourcepub async fn call_func_without_output<F, I>(
&self,
func: F,
input: I,
) -> Result<(), WarpgatePluginError>
pub async fn call_func_without_output<F, I>( &self, func: F, input: I, ) -> Result<(), WarpgatePluginError>
Call a function on the plugin with the given input and ignore the output.
Sourcepub async fn has_func(&self, func: impl AsRef<str>) -> bool
pub async fn has_func(&self, func: impl AsRef<str>) -> bool
Return true if the plugin has a function with the given id.
Sourcepub fn from_virtual_path(&self, path: impl AsRef<Path> + Debug) -> PathBuf
pub fn from_virtual_path(&self, path: impl AsRef<Path> + Debug) -> PathBuf
Convert the provided virtual guest path to an absolute host path.
Sourcepub fn to_virtual_path(&self, path: impl AsRef<Path> + Debug) -> VirtualPath
pub fn to_virtual_path(&self, path: impl AsRef<Path> + Debug) -> VirtualPath
Convert the provided absolute host path to a virtual guest path suitable for WASI sandboxed runtimes.