Struct warpgate::PluginContainer
source · pub struct PluginContainer {
pub id: Id,
pub manifest: Manifest,
/* private fields */
}Expand description
Fields
id: Idmanifest: ManifestImplementations
sourceimpl PluginContainer
impl PluginContainer
sourcepub fn new(
id: Id,
manifest: Manifest,
functions: impl IntoIterator<Item = Function>
) -> Result<PluginContainer>
pub fn new( id: Id, manifest: Manifest, functions: impl IntoIterator<Item = Function> ) -> Result<PluginContainer>
Create a new container with the provided manifest and host functions.
sourcepub fn new_without_functions(
id: Id,
manifest: Manifest
) -> Result<PluginContainer>
pub fn new_without_functions( id: Id, manifest: Manifest ) -> Result<PluginContainer>
Create a new container with the provided manifest.
sourcepub fn cache_func<O>(&self, func: &str) -> Result<O>where
O: Debug + DeserializeOwned,
pub fn cache_func<O>(&self, func: &str) -> Result<O>where
O: Debug + DeserializeOwned,
Call a function on the plugin with no input and cache the output before returning it. Subsequent calls will read from the cache.
sourcepub fn cache_func_with<I, O>(&self, func: &str, input: I) -> Result<O>
pub fn cache_func_with<I, O>(&self, func: &str, input: I) -> Result<O>
Call a function on the plugin with the given input and cache the output before returning it. Subsequent calls with the same input will read from the cache.
sourcepub fn call_func<O>(&self, func: &str) -> Result<O>where
O: Debug + DeserializeOwned,
pub fn call_func<O>(&self, func: &str) -> Result<O>where
O: Debug + DeserializeOwned,
Call a function on the plugin with no input and return the output.
sourcepub fn call_func_with<I, O>(&self, func: &str, input: I) -> Result<O>
pub fn call_func_with<I, O>(&self, func: &str, input: I) -> Result<O>
Call a function on the plugin with the given input and return the output.
sourcepub fn call_func_without_output<I>(&self, func: &str, input: I) -> Result<()>
pub fn call_func_without_output<I>(&self, func: &str, input: I) -> Result<()>
Call a function on the plugin with the given input and ignore the output.
sourcepub fn has_func(&self, func: &str) -> bool
pub fn has_func(&self, func: &str) -> bool
Return true if the plugin has a function with the given id.
sourcepub fn from_virtual_path(&self, path: impl AsRef<Path>) -> PathBuf
pub fn from_virtual_path(&self, path: impl AsRef<Path>) -> PathBuf
Convert the provided virtual guest path to an absolute host path.
sourcepub fn to_virtual_path(&self, path: impl AsRef<Path>) -> VirtualPath
pub fn to_virtual_path(&self, path: impl AsRef<Path>) -> VirtualPath
Convert the provided absolute host path to a virtual guest path suitable for WASI sandboxed runtimes.