pub struct PluginManifest {
pub wasm: Vec<Wasm>,
pub memory: MemoryOptions,
pub config: BTreeMap<String, String>,
pub allowed_hosts: Option<Vec<String>>,
pub allowed_paths: Option<BTreeMap<String, PathBuf>>,
pub timeout_ms: Option<u64>,
}Expand description
The Manifest type is used to configure the runtime and specify how to load modules.
Fields
wasm: Vec<Wasm>WebAssembly modules, the main module should be named main or listed last
memory: MemoryOptionsMemory options
config: BTreeMap<String, String>Config values are made accessible using the PDK extism_config_get function
allowed_hosts: Option<Vec<String>>Specifies which hosts may be accessed via HTTP, if this is empty then no hosts may be accessed. Wildcards may be used.
allowed_paths: Option<BTreeMap<String, PathBuf>>Specifies which paths should be made available on disk when using WASI. This is a mapping from
the path on disk to the path it should be available inside the plugin.
For example, ".": "/tmp" would mount the current directory as /tmp inside the module
timeout_ms: Option<u64>The plugin timeout in milliseconds
Implementations
Sourceimpl Manifest
impl Manifest
pub fn with_wasm(self, wasm: impl Into<Wasm>) -> Manifest
Sourcepub fn disallow_all_hosts(self) -> Manifest
pub fn disallow_all_hosts(self) -> Manifest
Disallow HTTP requests to all hosts
Sourcepub fn with_memory_options(self, memory: MemoryOptions) -> Manifest
pub fn with_memory_options(self, memory: MemoryOptions) -> Manifest
Set memory options
Sourcepub fn with_memory_max(self, max: u32) -> Manifest
pub fn with_memory_max(self, max: u32) -> Manifest
Set MemoryOptions::memory_max
Sourcepub fn with_allowed_host(self, host: impl Into<String>) -> Manifest
pub fn with_allowed_host(self, host: impl Into<String>) -> Manifest
Add a hostname to allowed_hosts
Sourcepub fn with_allowed_hosts(self, hosts: impl Iterator<Item = String>) -> Manifest
pub fn with_allowed_hosts(self, hosts: impl Iterator<Item = String>) -> Manifest
Set allowed_hosts
Sourcepub fn with_allowed_path(self, src: String, dest: impl AsRef<Path>) -> Manifest
pub fn with_allowed_path(self, src: String, dest: impl AsRef<Path>) -> Manifest
Add a path to allowed_paths
Sourcepub fn with_allowed_paths(
self,
paths: impl Iterator<Item = (String, PathBuf)>,
) -> Manifest
pub fn with_allowed_paths( self, paths: impl Iterator<Item = (String, PathBuf)>, ) -> Manifest
Set allowed_paths
Sourcepub fn with_config(
self,
c: impl Iterator<Item = (impl Into<String>, impl Into<String>)>,
) -> Manifest
pub fn with_config( self, c: impl Iterator<Item = (impl Into<String>, impl Into<String>)>, ) -> Manifest
Set config
Sourcepub fn with_config_key(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Manifest
pub fn with_config_key( self, k: impl Into<String>, v: impl Into<String>, ) -> Manifest
Set a single config key
Sourcepub fn with_timeout(self, timeout: Duration) -> Manifest
pub fn with_timeout(self, timeout: Duration) -> Manifest
Set timeout_ms, which will interrupt a plugin function’s execution if it meets or
exceeds this value. When an interrupt is made, the plugin will not be able to recover and
continue execution.